@@ -25,7 +25,7 @@ class TestBTM(unittest.TestCase):
         LOGGER.info('Modeling started')
         model = btm.BTM(X, vocab, T=8, W=vocab.size, M=20, alpha=50/8, beta=0.01)
         # t1 = time.time()
-        model.fit(biterms, iterations=20)
+        model.fit(biterms, seed=12345, iterations=20)
         # t2 = time.time()
         # LOGGER.info(t2 - t1)
         self.assertIsInstance(model.matrix_topics_words_, np.ndarray)
